"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const crypto = require("crypto");
const webcrypto_js_1 = require("./webcrypto.js");
const secret_key_js_1 = require("./secret_key.js");
function getSignVerifyKey(alg, key, usage) {
    if (key instanceof crypto.KeyObject) {
        return key;
    }
    if (key instanceof Uint8Array) {
        if (!alg.startsWith('HS')) {
            throw new TypeError('symmetric keys are only applicable for HMAC-based JWA algorithms');
        }
        return secret_key_js_1.default(key);
    }
    if (webcrypto_js_1.isCryptoKey(key)) {
        return webcrypto_js_1.getKeyObject(key, alg, new Set([usage]));
    }
    throw new TypeError('invalid key input');
}
exports.default = getSignVerifyKey;
